FlutterAuthenticationKeyManager class
Implementation of a Serverpod AuthenticationKeyManager specifically for
Flutter. Authentication key is stored in the SharedPreferences.
Constructors
- FlutterAuthenticationKeyManager({String runMode = 'production', Storage? storage})
- Creates a new authentication key manager. By default it uses the shared preferences for storing keys.
Properties
-
authHeaderValue
→ Future<
String?> -
Backwards compatible authentication header value getter.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runMode → String
-
The run mode of the Serverpod.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
) → Future< String?> - Retrieves an authentication key.
-
getHeaderValue(
) → Future< String?> -
Retrieves the authentication key in a format that can be used in a transport header.
The format conversion is performed by
toHeaderValue.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
String key) → Future< void> - Saves an authentication key retrieved by the server.
-
remove(
) → Future< void> - Removes the authentication key.
-
toHeaderValue(
String? key) → Future< String?> - Converts an authentication key to a format that can be used in a transport header. This will automatically be unwrapped again on the server side before being handed to the authentication handler.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited